@@ -14,8 +14,8 @@ exports.read = function(params, cb) {
     params = {'key': 'git2consul/config'};
   }
 
-  if (process.env.TOKEN) {
-    params = _.extend(params, {'token': process.env.TOKEN})
+  if (global.token) {
+    params = _.extend(params, {'token': global.token})
   }
   consul.kv.get(params, function(err, item) {
     if (err) return cb(err);
